Welcome to nglpy's documentation!
=================================

Neighborhood Graph Library

.. toctree::
   :maxdepth: 2

   install.rst
   usage.rst
   api.rst
   license.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
